@@ -2,18 +2,15 @@ import os
 import csv
 import time
 import torch
-import logging
 from filelock import FileLock
 from dataclasses import dataclass
 from typing import List, Optional
+from ratsnlp.nlpbook.utils import logger
 from torch.utils.data.dataset import Dataset
 from transformers import PreTrainedTokenizerFast
 from ratsnlp.nlpbook.generation.arguments import GenerationTrainArguments
 
 
-logger = logging.getLogger("ratsnlp")
-
-
 @dataclass
 class GenerationExample:
     text: str
@@ -142,7 +139,7 @@ class GenerationDataset(Dataset):
                     args,
                 )
                 start = time.time()
-                logging.info(
+                logger.info(
                     "Saving features into cached file, it could take a lot of time..."
                 )
                 torch.save(self.features, cached_features_file)
