@@ -1,9 +1,8 @@
 import os
 import json
-import logging
+from ratsnlp.nlpbook.utils import logger
 from ratsnlp.nlpbook.classification.corpus import ClassificationExample
 
-logger = logging.getLogger("ratsnlp")
 
 
 class KlueNLICorpus:
