@@ -2,21 +2,18 @@ import os
 import time
 import json
 import torch
-import logging
 from tqdm import tqdm
 from functools import partial
 from filelock import FileLock
 from dataclasses import dataclass
 from typing import List, Optional
+from ratsnlp.nlpbook.utils import logger
 from multiprocessing import Pool, cpu_count
 from transformers import PreTrainedTokenizer
 from torch.utils.data.dataset import Dataset
 from ratsnlp.nlpbook.qa import QATrainArguments
 
 
-logger = logging.getLogger("ratsnlp")
-
-
 @dataclass
 class QAExample:
     # 질문 : 임종석이 여의도 농민 폭력 시위를 주도한 혐의로 지명수배 된 날은?
@@ -380,7 +377,7 @@ class QADataset(Dataset):
                 examples = self.corpus.get_examples(corpus_fpath, mode)
                 self.features = convert_examples_to_features_fn(examples, tokenizer, args)
                 start = time.time()
-                logging.info(
+                logger.info(
                     "Saving features into cached file, it could take a lot of time..."
                 )
                 torch.save(self.features, cached_features_file)
