@@ -1,12 +1,9 @@
 import os
 import sys
 import tqdm
-import torch
 import logging
 import requests
-from transformers import set_seed
 from transformers import HfArgumentParser
-from pytorch_lightning import _logger as lightning_logger
 
 
 REMOTE_DATA_MAP = {
@@ -74,6 +71,7 @@ REMOTE_MODEL_MAP = {
 }
 GOOGLE_DRIVE_URL = "https://docs.google.com/uc?export=download"
 logger = logging.getLogger("ratsnlp")  # pylint: disable=invalid-name
+logger.setLevel(logging.INFO)
 
 
 def save_response_content(response, save_path):
@@ -213,20 +211,6 @@ def download_pretrained_model(args, config_only=False):
         raise ValueError(f"not valid model name({pretrained_model_name}), cannot download resources")
 
 
-def set_logger(args):
-    if torch.cuda.is_available():
-        # 파이토치 라이트닝이 학습 초반부에 로그를 두 번씩 찍는 버그가 있어
-        # 이를 해결하기 위해 handler를 빈 리스트로 초기화한다
-        lightning_logger.handlers = []
-    logger.setLevel(logging.INFO)
-    logger.info("Training/evaluation parameters %s", args)
-
-
-def seed_setting(args):
-    set_seed(args.seed)
-    logger.info(f"complete setting seed({args.seed})")
-
-
 def load_arguments(argument_class, json_file_path=None):
     parser = HfArgumentParser(argument_class)
     if json_file_path is not None:
